@@ -1,7 +1,6 @@
 /**
  * @file xml.h
  * @defgroup xml XML API
- * @{
  */
 
 #ifndef ISMRMRDXML_H
@@ -26,6 +25,10 @@
 
  */
 
+/**
+ * @addtogroup xml
+ * @{
+ */
 
 namespace ISMRMRD
 {
@@ -81,25 +84,70 @@ namespace ISMRMRD
       return present_;
     }
 
-    T& get() {
+    bool has_value() const noexcept {
+        return present_;
+    }
+
+
+  T &value() &{
       if (!present_) {
-	throw std::runtime_error("Access optional value, which has not been set");
+          throw std::runtime_error("Access optional value, which has not been set");
       }
       return value_;
-    }
+  }
 
 
-    const T& get() const  {
+  const T &value() const &{
       if (!present_) {
-	throw std::runtime_error("Access optional value, which has not been set");
+          throw std::runtime_error("Access optional value, which has not been set");
       }
       return value_;
+  }
+
+  T &&value() &&{
+      if (!present_) {
+          throw std::runtime_error("Access optional value, which has not been set");
+      }
+      return std::move(value_);
+  }
+
+  const T &&value() const &&{
+      if (!present_) {
+          throw std::runtime_error("Access optional value, which has not been set");
+      }
+      return std::move(value_);
+  }
+
+  T &get() & {
+      return  this->value();
     }
 
-    
-    T& operator()() {
-      return get();
+    T&& get()&&{
+        return this->value();
     }
+     const T &get() const &  {
+          return  this->value();
+      }
+
+     const  T&& get() const &&{
+          return this->value();
+      }
+  template<class U>
+  T value_or(U &&default_value) const &{
+      return bool(*this) ? **this : static_cast<T>(std::forward<U>(default_value));
+  }
+
+  template<class U>
+  T value_or(U &&default_value) &&{
+      return bool(*this) ? std::move(**this) : static_cast<T>(std::forward<U>(default_value));
+  }
+
+
+
+
+  T& operator()() {
+  return value();
+}
 
     void set(const T& v) {
       present_ = true;
@@ -112,6 +160,13 @@ namespace ISMRMRD
 
   }; 
 
+  struct threeDimensionalFloat
+  {    
+    float x;
+    float y;
+    float z;
+  };
+
   struct SubjectInformation 
   {
     Optional<std::string> patientName;
@@ -149,6 +204,7 @@ namespace ISMRMRD
     Optional<std::string> seriesDate;
     Optional<std::string> seriesTime;
     std::string patientPosition;
+    Optional<threeDimensionalFloat> relativeTablePosition;
     Optional<long int> initialSeriesNumber;
     Optional<std::string> protocolName;
     Optional<std::string> seriesDescription;
@@ -174,6 +230,7 @@ namespace ISMRMRD
     std::vector<CoilLabel> coilLabel;
     Optional<std::string> institutionName;
     Optional<std::string> stationName;
+    Optional<std::string> deviceID;
   };
 
 
@@ -374,10 +431,11 @@ namespace ISMRMRD
   };
 
 
-
   EXPORTISMRMRD void deserialize(const char* xml, IsmrmrdHeader& h);
   EXPORTISMRMRD void serialize(const IsmrmrdHeader& h, std::ostream& o);
-}
 
 /** @} */
+
+}
+
 #endif //ISMRMRDXML_H
