@@ -1,10 +1,12 @@
 /* Language and Cross platform section for defining types */
 #ifdef __cplusplus
+#include <cstddef>
 #include <cstring>
 #include <cstdlib>
 #include <cstdio>
 #else
 /* C99 compiler */
+#include <stddef.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -598,7 +600,7 @@ static uint32_t get_number_of_elements(const ISMRMRD_Dataset *dset, const char *
         dims = (hsize_t *) malloc(rank*sizeof(hsize_t));
         maxdims = (hsize_t *) malloc(rank*sizeof(hsize_t));
         h5status = H5Sget_simple_extent_dims(dataspace, dims, maxdims);
-        num = dims[0];
+        num = (uint32_t)dims[0];
         free(dims);
         free(maxdims);
         h5status = H5Sclose(dataspace);
@@ -1173,9 +1175,9 @@ int ismrmrd_append_acquisition(const ISMRMRD_Dataset *dset, const ISMRMRD_Acquis
 
     /* Create the HDF5 version of the acquisition */
     hdf5acq[0].head = acq->head;
-    hdf5acq[0].traj.len = acq->head.number_of_samples * acq->head.trajectory_dimensions;
+    hdf5acq[0].traj.len = (size_t)(acq->head.number_of_samples) * (size_t)(acq->head.trajectory_dimensions);
     hdf5acq[0].traj.p = acq->traj;
-    hdf5acq[0].data.len = 2 * acq->head.number_of_samples * acq->head.active_channels;
+    hdf5acq[0].data.len = 2 * (size_t)(acq->head.number_of_samples) * (size_t)(acq->head.active_channels);
     hdf5acq[0].data.p = acq->data;
 
     /* Write it */
@@ -1425,7 +1427,7 @@ int ismrmrd_append_waveform(const ISMRMRD_Dataset *dset, const ISMRMRD_Waveform
 
     /* Create the HDF5 version of the acquisition */
     hdf5wav[0].head = wav->head;
-    hdf5wav[0].data.len = wav->head.number_of_samples * wav->head.channels;
+    hdf5wav[0].data.len = (size_t)(wav->head.number_of_samples) * (size_t)(wav->head.channels);
     hdf5wav[0].data.p = wav->data;
 
     /* Write it */
