@@ -1,5 +1,6 @@
 #include <string.h>
 #include <stdlib.h>
+#include <stdint.h>
 
 /* Language and Cross platform section for defining types */
 #ifdef __cplusplus
@@ -396,7 +397,11 @@ int ismrmrd_copy_ndarray(ISMRMRD_NDArray *arrdest, const ISMRMRD_NDArray *arrsou
     if (ismrmrd_make_consistent_ndarray(arrdest)!=ISMRMRD_NOERROR) {
         return ISMRMRD_PUSH_ERR(ISMRMRD_RUNTIMEERROR, "Failed to make ndarray consistent.");
     }
-    memcpy(arrdest->data, arrsource->data, ismrmrd_size_of_ndarray_data(arrdest));
+    if (arrsource->data == NULL) {
+        arrdest->data = NULL;
+    } else {
+        memcpy(arrdest->data, arrsource->data, ismrmrd_size_of_ndarray_data(arrdest));
+    }
     return ISMRMRD_NOERROR;
 }
 
@@ -548,7 +553,7 @@ int ismrmrd_set_channel_off(uint64_t channel_mask[ISMRMRD_CHANNEL_MASKS], const
     if (channel_mask==NULL) {
         return ISMRMRD_PUSH_ERR(ISMRMRD_RUNTIMEERROR, "Pointer to channel_mask should not be NULL.");
     }
-    bitmask = 1 << (chan % 64);
+    bitmask = UINT64_C(1) << (chan % 64);
     offset = chan / 64;
     channel_mask[offset] &= ~bitmask;
     return ISMRMRD_NOERROR;
