@@ -24,9 +24,9 @@ namespace ISMRMRD
     if (!fieldOfView_mm) {
       throw std::runtime_error("fieldOfView_mm not found in encodingSpace");
     } else {
-      e.fieldOfView_mm.x = std::atof(fieldOfView_mm.child_value("x"));
-      e.fieldOfView_mm.y = std::atof(fieldOfView_mm.child_value("y"));
-      e.fieldOfView_mm.z = std::atof(fieldOfView_mm.child_value("z"));
+      e.fieldOfView_mm.x = std::strtof(fieldOfView_mm.child_value("x"), nullptr);
+      e.fieldOfView_mm.y = std::strtof(fieldOfView_mm.child_value("y"), nullptr);
+      e.fieldOfView_mm.z = std::strtof(fieldOfView_mm.child_value("z"), nullptr);
     }
 
     return e;
@@ -68,7 +68,7 @@ namespace ISMRMRD
     Optional<float> r;
     pugi::xml_node nc = n.child(child);
     if (nc) {
-      r = std::atof(nc.child_value());
+      r = std::strtof(nc.child_value(), nullptr);
     }
     return r;
   }
@@ -98,7 +98,7 @@ namespace ISMRMRD
     pugi::xml_node nc = n.child(child);
 
     while (nc) {
-      float f = std::atof(nc.child_value());
+      float f = std::strtof(nc.child_value(), nullptr);
       r.push_back(f);
       nc = nc.next_sibling(child);
     }
@@ -118,6 +118,22 @@ namespace ISMRMRD
     return r;
   }
 
+  Optional<threeDimensionalFloat> parse_optional_threeDimensionalFloat(pugi::xml_node &n, const char *child) {
+
+      Optional<threeDimensionalFloat> r;
+    
+      pugi::xml_node nc = n.child(child);
+      if (nc) {
+          threeDimensionalFloat s;
+          s.x = std::strtof(nc.child_value("x"), nullptr);
+          s.y = std::strtof(nc.child_value("y"), nullptr);
+          s.z = std::strtof(nc.child_value("z"), nullptr);
+          r = s;
+      }
+
+      return r;
+  }
+
   std::vector<UserParameterLong> parse_user_parameter_long(pugi::xml_node& n, const char* child) 
   {
     std::vector<UserParameterLong> r;
@@ -314,7 +330,7 @@ namespace ISMRMRD
 	      traj.comment = parse_optional_string(trajectoryDescription, "comment");
 	      e.trajectoryDescription = traj;
 	    } catch (std::runtime_error& e) {
-	      std::cout << "Error parsing trajectory description" << std::endl;
+	      std::cout << "Error parsing trajectory description: " << e.what() << std::endl;
 	      throw;
 	    }
 	    
@@ -373,6 +389,7 @@ namespace ISMRMRD
 	info.seriesDate = parse_optional_string(measurementInformation, "seriesDate");
 	info.seriesTime = parse_optional_string(measurementInformation, "seriesTime");
 	info.patientPosition = parse_string(measurementInformation, "patientPosition");
+	info.relativeTablePosition = parse_optional_threeDimensionalFloat(measurementInformation, "relativeTablePosition");
 	info.initialSeriesNumber = parse_optional_long(measurementInformation, "initialSeriesNumber");
 	info.protocolName = parse_optional_string(measurementInformation, "protocolName");
 	info.seriesDescription = parse_optional_string(measurementInformation, "seriesDescription");
@@ -426,7 +443,7 @@ namespace ISMRMRD
 	}
 	info.institutionName = parse_optional_string(acquisitionSystemInformation, "institutionName");
 	info.stationName = parse_optional_string(acquisitionSystemInformation, "stationName");
-
+    info.deviceID = parse_optional_string(acquisitionSystemInformation,"deviceID");
 	h.acquisitionSystemInformation = info;
       }
 
@@ -601,6 +618,15 @@ namespace ISMRMRD
     append_node(n3,"z",s.fieldOfView_mm.z);
   }
 
+void append_optional_three_dimensional_float(pugi::xml_node& n, const char* child, const Optional<threeDimensionalFloat>& s) 
+  {
+    if (s){
+      pugi::xml_node n2 = n.append_child(child);  
+      append_node(n2,"x",s->x);
+      append_node(n2,"y",s->y);
+      append_node(n2,"z",s->z);
+    }
+  }
   void append_encoding_limit(pugi::xml_node& n, const char* child, const Optional<Limit>& l) 
   {
     if (l) {
@@ -695,6 +721,7 @@ namespace ISMRMRD
       append_optional_node(n1,"seriesDate",h.measurementInformation->seriesDate);
       append_optional_node(n1,"seriesTime",h.measurementInformation->seriesTime);
       append_node(n1,"patientPosition",h.measurementInformation->patientPosition);
+      append_optional_three_dimensional_float(n1,"relativeTablePosition",h.measurementInformation->relativeTablePosition);
       append_optional_node(n1,"initialSeriesNumber",h.measurementInformation->initialSeriesNumber);
       append_optional_node(n1,"protocolName",h.measurementInformation->protocolName);
       append_optional_node(n1,"seriesDescription",h.measurementInformation->seriesDescription);
@@ -736,6 +763,7 @@ namespace ISMRMRD
       }
       append_optional_node(n1,"institutionName",h.acquisitionSystemInformation->institutionName);
       append_optional_node(n1,"stationName",h.acquisitionSystemInformation->stationName);
+      append_optional_node(n1,"deviceID",h.acquisitionSystemInformation->deviceID);
     }
 
     n1 = root.append_child();
