@@ -34,7 +34,12 @@ for n = 1:numChildNodes
     name = char(getNodeName(theChild));
 
     %Some elements occur more than once
-    if isfield(info,name)
+    if isfield(info, name)
+        % Use cell arrays for multiple valued strings and dates
+        if (isStringType(name) || isDateType(name)) && ~iscell(info.(name))
+            info.(name) = {info.(name)};
+        end
+
         num = length(info.(name))+1;
     else
         num = 1;
@@ -88,7 +93,7 @@ for n = 1:numChildNodes
         if num == 1
             info.(name) = char(getTextContent(theChild));
         else
-            info.(name)(num) = char(getTextContent(theChild));
+            info.(name){num} = char(getTextContent(theChild));
         end
         continue;
     end
@@ -106,7 +111,7 @@ for n = 1:numChildNodes
         if num == 1
             info.(name) = char(getTextContent(theChild));
         else
-            info.(name)(num) = char(getTextContent(theChild));
+            info.(name){num} = char(getTextContent(theChild));
         end
         continue;
     end
@@ -166,6 +171,7 @@ function status = isCompoundType(name)
         'accelerationFactor', ...
         'matrixSize', ...
         'fieldOfView_mm', ...
+        'relativeTablePosition', ...
         'kspace_encoding_step_0', ...
         'kspace_encoding_step_1', ...
         'kspace_encoding_step_2', ...
@@ -185,7 +191,7 @@ end
 function status = isNumericalType(name)
     headerNumericalTypes = { ...
       'version', ...
-      'patientWeight', ...
+      'patientWeight_kg', ...
       'accessionNumber', ...
       'initialSeriesNumber', ...
       'systemFieldStrength_T', ...
@@ -227,8 +233,10 @@ function status = isStringType(name)
       'systemModel', ...
       'institutionName', ...
       'stationName', ...
+      'deviceID', ...
       'trajectory', ...
       'identifier', ...
+      'comment', ...
       'coilName', ...
       'calibrationMode',...
       'interleavingDimension',...
